#
# spec file for package mingw64-runtime
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mingw64-runtime
Version:        11.0.1
Release:        1.2
Summary:        MinGW-w64 runtime libraries for Win64
License:        SUSE-Public-Domain
Group:          Development/Libraries/C and C++
URL:            http://mingw-w64.sf.net/
Source:         http://downloads.sf.net/mingw-w64/mingw-w64-v%{version}.tar.bz2
Source100:      %{name}-rpmlintrc
BuildRequires:  mingw64-cross-binutils
BuildRequires:  mingw64-cross-gcc-bootstrap >= 4.4.0
BuildRequires:  mingw64-filesystem
BuildRequires:  mingw64-headers >= %{version}
BuildRequires:  xz
#!BuildIgnore:  post-build-checks
# When building the CRT, any newer (>=) headers should be ok, since the CRT
# won't make use of them. At runtime, ensure that headers are not too new (<=)
# because ominous link failures can result -- let OBS go into unresolvable
# state instead.
Requires:       mingw64-headers <= %{version}
# Once this is installed, mingw64-bootstrap (binary bootstrapper) is no
# longer needed.
Obsoletes:      mingw64-runtime-bootstrap
BuildArch:      noarch
%_mingw64_package_header_debug

%description
MinGW Win64 cross-compiler runtime, base libraries.

%prep
%autosetup -n mingw-w64-v%{version}/mingw-w64-crt

%build
%{_mingw64_configure} --disable-lib32 --enable-lib64
%make_build

%install
%make_install
rm -Rfv "%{buildroot}/%{_mingw64_includedir}"/*.c

%files
%{_mingw64_libdir}/

%changelog
* Fri Nov  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 11.0.1
  * New Hyper-V APIs
  * Updates to DX12 headers and much more from Wine
  * Many other new Win32 APIs
* Mon Jun 27 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 10
  * New msvcrt10, 20, 40, 70 and 71 import libraries.
  * Drop x86_64 64-bit crtdll.dll
  * Updated wine imports
* Sat Jul  3 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 9.0.0
  * UCRT updates, Wine updates
  * gettimeofday precision increase
* Thu Dec  3 2020 Tobias Klausmann <tobias.klausmann@freenet.de>
- Update to new upstream release 8.0.0
  * New Hyper-V headers and libraries by Biswapriyo Nath
  * Many headers updated from Wine by Jacek Caban.
  * ARM math improvements by Martin Storsjö
  * floating point fixes by Liu Hao
  * many *printf compatibility fixes by Liu Hao and Martin Storsjö
  * massive Windows App Store API updates by Steve Lhomme
  * winstorecompat library updates by Martin Storsjö
  * __USE_MINGW_ANSI_STDIO now automatically enabled in C99 and C11 mode when
    not using UCRT by Pali Rohár
  * wdm and ddk updates by Zebediah Figura
  * UCRT for Windows Store Apps (-lucrtapp) by Martin Storsjö
  * Audioclient and ActivateAudioInterfaceAsync API updates by Liu Hao
  * DirectX SDKs are now always installed
* Sat Nov 23 2019 Ismail Dönmez <idonmez@suse.com>
- Update to new upstream release 7.0.0
  * _FORTIFY_SOURCE support thanks to Christian Franke.
  * Lots of math fixes from Martin Storsjö.
  * Many headers updated from Wine by Jacek Caban.
  * UCRT support by Martin Storsjö.
* Wed Oct 17 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 6.0.0
  * C++ __cxa_atexit
  * Massive additions to support UCRT
  * Sync COM interface headers with Wine development
  * WinRT additions
  * ARM32 and ARM64 additions
  * CRT library api-ms-win-core additions
  * CRT library def file reorganization
- Removed popcnt.patch, 0001-Add-missing-D3D_CS_-variables.patch
  (no longer needed; included upstream)
* Tue Nov 21 2017 idonmez@suse.com
- Update to version 5.0.3
- Drop libmsvcrt.a-Added-_create_locale-and-_free_locale-ent.diff,
  fixed upstream.
* Tue Apr 18 2017 idonmez@suse.com
- Add libmsvcrt.a-Added-_create_locale-and-_free_locale-ent.diff
* Tue Mar 28 2017 idonmez@suse.com
- Update to version 5.0.2
* Sat Jan 14 2017 idonmez@suse.com
- Update to version 5.0.1
* Wed Mar 23 2016 jengelh@inai.de
- Update to new upstream release 5.0~rc1
  * Basic ARM support
  * gcc-5 support
* Fri Sep  4 2015 idonmez@suse.com
- Update to version 4.0.4
  * No changelog upstream
* Tue Apr 21 2015 jengelh@inai.de
- Update to new upstream release 4.0.2
  * Fix 64bit __mingw_printf %%l*, %%z* and %%g
* Tue Mar 31 2015 jengelh@inai.de
- Add mkstemp.diff, addressing broken behavior of mkstemp(),
  a newly implemented function since mingw 4.0.1.
* Thu Mar 26 2015 jengelh@inai.de
- Update to new upstream release 4.0.1
  * 32-bit ARM thumb software math
  * Improved DirectX 11, OpenGL 4.5/GLES 3.1 support
  * added POSIX.1-2008 ftw.h
  * more secure functions: qsort_s, gmtime64_s, time_s.h, ...
  * added to stat.h: S_IRGRP, S_IRWXG, ...
  * added to unistd.h: SHUT_*
* Tue Dec 20 2011 dev@dominik-schmidt.de
- apply patch from trunk, that fixes crash on startup on certain systems
